from . import hpm

def main():
    hpm.main()

if __name__ == "__main__":
    main()